@@ -14,6 +14,7 @@ from six import with_metaclass
 from m3_gar_client.backends.m3_rest_gar.proxy.utils import PlaceLoader
 from m3_gar_client.backends.m3_rest_gar.proxy.utils import StreetLoader
 from m3_gar_client.backends.m3_rest_gar.proxy.utils import UIHouseLoader
+from m3_gar_client.backends.m3_rest_gar.proxy.utils import UISteadLoader
 from m3_gar_client.utils import correct_keyboard_layout
 
 
@@ -104,6 +105,37 @@ class HouseSearchAction(ParentMixin, ActionBase):
         return UIHouseLoader(context.filter, parent_id=context.parent)
 
 
+class HouseOrSteadSearchAction(ParentMixin, ActionBase):
+    """
+    Обработчик запросов на поиск домов и земельных участков.
+    """
+
+    url = '/search/house_or_stead'
+    correct_keyboard_input = False
+
+    def run(self, request, context):
+        if self.correct_keyboard_input:
+            context.filter = correct_keyboard_layout(context.filter)
+
+        loader_of_houses = self._get_loader(context)
+        loader_of_steads = self.get_steads(context)
+        rows = loader_of_houses.load()
+        rows.extend(loader_of_steads.load())
+
+        return JsonResponse({
+            'rows': rows,
+            'total': len(rows),
+        })
+
+    def _get_loader(self, context):
+        # pylint: disable=abstract-class-instantiated
+        return UIHouseLoader(context.filter, parent_id=context.parent)
+
+    def get_steads(self, context):
+        # pylint: disable=abstract-class-instantiated
+        return UISteadLoader(context.filter, parent_id=context.parent)
+
+
 class Pack(ActionPack):
     """
     Набор действий для проксирования запросов к серверу ГАР.
