@@ -11,6 +11,9 @@ from itertools import (
     count,
 )
 
+from six import with_metaclass
+from six import text_type
+from six import iteritems
 from six.moves import (
     http_client,
     map,
