@@ -130,3 +130,6 @@ GAR_HIERARCHIES = (
 )
 
 DEFAULT_PAGE_LIMIT = 20
+
+# Длительность кэширования по умолчанию 24 часа
+DEFAULT_CACHE_TIMEOUT = 24 * 60 * 60
